@@ -1,29 +1,21 @@
-from abc import ABCMeta, abstractmethod
+import time
+from abc import ABCMeta
 from .individual import Individual
 
 
 class Job(metaclass=ABCMeta):
-    def __init__(self, problem, population):
+    def __init__(self, problem, population=None):
         self.problem = problem
         self.population = population
 
-    @abstractmethod
-    def evaluate(self, x):
-        pass
-
-    def evaluate_scalar(self, x):
-        # simple individual
-        individual = Individual(x)
-        self.evaluate(individual)
-
-        return individual.costs[0]
-
-
-class JobSimple(Job):
-    def __init__(self, problem, population=None):
-        super().__init__(problem, population)
-
     def evaluate(self, individual):
+        # info
+        individual.info["start_time"] = time.time()
+        t_s = time.time()
+
+        # set in progress
+        individual.state = individual.State.IN_PROGRESS
+
         # check the constraints
         constraints = self.problem.evaluate_constraints(individual)
 
@@ -42,13 +34,19 @@ class JobSimple(Job):
             individual.state = individual.State.EVALUATED
 
         except (TimeoutError, RuntimeError) as e:
-            # individual.vector = VectorAndNumbers.gen_vector(self.problem.parameters)
             individual.state = Individual.State.FAILED
 
         # add to population
         if self.population is not None:
             self.population.individuals.append(individual)
+            individual.info["population"] = self.problem.populations.index(self.population)
 
-        # write to datastore
-        self.problem.data_store.write_individual(individual)
+        # info
+        individual.info["finish_time"] = time.time()
 
+    def evaluate_scalar(self, x):
+        # simple individual
+        individual = Individual(x)
+        self.evaluate(individual)
+
+        return individual.costs[0]
