@@ -28,7 +28,7 @@ class SurrogateModel(metaclass=ABCMeta):
         self.y_data.append(y)
 
     def read_from_data_store(self):
-        for population in self.problem.data_store.populations:
+        for population in self.problem.populations:
             for individual in population.individuals:
                 self.add_data(individual.vector, individual.costs)
 
