@@ -1,19 +1,19 @@
 import unittest
 # from artap.doe import build_box_behnken, build_lhs, build_frac_fact, build_full_fact, build_plackett_burman
 # from artap.individual import Individual
-from artap.operators import CustomGeneration, RandomGeneration, FullFactorGeneration, PlackettBurmanGeneration, \
-    BoxBehnkenGeneration, LHSGeneration, GradientGeneration
+from artap.operators import CustomGenerator, RandomGenerator, FullFactorGenerator, PlackettBurmanGenerator, \
+    BoxBehnkenGenerator, LHSGenerator
 
 
 class TestDOE(unittest.TestCase):
 
     def setUp(self):
         self.parameters = [{'name': 'x_1', 'initial_value': 2.5, 'bounds': [-2.5, 5]},
-                           {'name': 'x_2','initial_value': 1.5, 'bounds': [1, 3.4]},
-                           {'name': 'x_3','initial_value': 3.5, 'bounds': [6, 10]}]
+                           {'name': 'x_2', 'initial_value': 1.5, 'bounds': [1, 3.4]},
+                           {'name': 'x_3', 'initial_value': 3.5, 'bounds': [6, 10]}]
 
     def test_random_generator(self):
-        gen = RandomGeneration(parameters=self.parameters)
+        gen = RandomGenerator(parameters=self.parameters)
         gen.init(3)
         individuals = gen.generate()
         # values
@@ -28,7 +28,7 @@ class TestDOE(unittest.TestCase):
                         self.parameters[2]['bounds'][0] <= individuals[2].vector[2] <= self.parameters[2]['bounds'][1])
 
     def test_custom_generator(self):
-        gen = CustomGeneration()
+        gen = CustomGenerator()
         gen.init([[3, 2, 6], [-1, 3, 8]])
         individuals = gen.generate()
         # values
@@ -42,7 +42,7 @@ class TestDOE(unittest.TestCase):
     # Factorial Designs
     def test_full_fact_generator(self):
         # General Full-Factorial
-        gen = FullFactorGeneration(parameters=self.parameters)
+        gen = FullFactorGenerator(parameters=self.parameters)
         gen.init(center=False)
         individuals = gen.generate()
 
@@ -55,7 +55,7 @@ class TestDOE(unittest.TestCase):
         self.assertEqual(individuals[3].vector[1], 3.4)
         self.assertEqual(individuals[7].vector[2], 10.0)
 
-        gen = FullFactorGeneration(parameters=self.parameters)
+        gen = FullFactorGenerator(parameters=self.parameters)
         gen.init(center=True)
         individuals = gen.generate()
 
@@ -64,7 +64,7 @@ class TestDOE(unittest.TestCase):
 
     def test_plackett_burman_generator(self):
         # Plackett-Burman
-        gen = PlackettBurmanGeneration(parameters=self.parameters)
+        gen = PlackettBurmanGenerator(parameters=self.parameters)
         individuals = gen.generate()
 
         # size
@@ -78,7 +78,7 @@ class TestDOE(unittest.TestCase):
     # Response - Surface Designs
     def test_box_behnken_generator(self):
         # Box-Behnken
-        gen = BoxBehnkenGeneration(parameters=self.parameters)
+        gen = BoxBehnkenGenerator(parameters=self.parameters)
         individuals = gen.generate()
 
         # size
@@ -92,7 +92,7 @@ class TestDOE(unittest.TestCase):
     # Randomized Designs
     def test_lhs_generation(self):
         # Latin - Hypercube
-        gen = LHSGeneration(parameters=self.parameters)
+        gen = LHSGenerator(parameters=self.parameters)
         gen.init(number=3)
         individuals = gen.generate()
 
@@ -109,17 +109,6 @@ class TestDOE(unittest.TestCase):
                         self.parameters[1]['bounds'][0] <= individuals[2].vector[1] <= self.parameters[1]['bounds'][1] and
                         self.parameters[2]['bounds'][0] <= individuals[2].vector[2] <= self.parameters[2]['bounds'][1])
 
-    def test_gradient_generation(self):
-        # gradient
-        gen = LHSGeneration(parameters=self.parameters)
-        gen.init(number=3)
-        individuals = gen.generate()
-        gen = GradientGeneration(self.parameters)
-        gen.init(individuals)
-        new_individuals = gen.generate()
-        # size
-        self.assertEqual(len(new_individuals), 9)
-
 
 if __name__ == '__main__':
     unittest.main()
